import json
import unittest2 as unittest

# from django_alexa.api import ResponseBuilder


class TestAlexaApi(unittest.TestCase):
    
    def test_response_builder(self):
        # data = {
        #    'outputSpeech': {
        #         'type': "PlainText",
        #         'text': "This is a test!",
        #     },
        #     'shouldEndSession': True,          
        # }
        # response = ResponseBuilder(message="This is a test!")
        # self.assertEquals(json.dumps(response.data),
        #                   json.dumps(data))
        pass



from __future__ import absolute_import
from .api import intent, ResponseBuilder


@intent
def LaunchRequest():
    """Default Start Session Intent"""
    return ResponseBuilder.create_response(message="Welcome. Say help if you would like help. What would you like to do next?",
                                           reprompt="What would you like to do next?",
                                           end_session=False)


@intent
def CancelIntent():
    """Default Cancel Intent"""
    return ResponseBuilder.create_response(message="Actions Canceled! What would you like to do next?",
                                           reprompt="What would you like to do next?",
                                           end_session=False)


@intent
def StopIntent():
    """Default Stop Intent"""
    return ResponseBuilder.create_response(message="Stopping Actions. Goodbye!")


@intent
def HelpIntent():
    """Default Help Intent"""
    return ResponseBuilder.create_response(message="No help was configured!")


@intent
def SessionEndedRequest():
    """Default End Session Intent"""
    return ResponseBuilder.create_response(message="Have a nice day. Goodbye!")



from __future__ import absolute_import
from django.core.management.base import BaseCommand
from ...api import IntentsSchema


class Command(BaseCommand):
    help = 'Prints the Alexa Skills Kit utterances schema'

    def handle(self, *args, **options):
        data = IntentsSchema.generate_utterances()
        self.stdout.write('\n'.join(data))



from __future__ import absolute_import
from django.conf.urls import url, include
from rest_framework import routers
from .views import ASKViewSet

router = routers.DefaultRouter()
router.register(r"ask", ASKViewSet, base_name="ask")
router.include_root_view = False

urlpatterns = [
    url(r'^alexa/', include(router.urls), name="alexa"),
]



from __future__ import absolute_import
from rest_framework.serializers import Serializer as Slots  # flake8: noqa
from . import validation, fields  # flake8: noqa
from .intents_schema import intent, IntentsSchema  # flake8: noqa
from .response_builder import ResponseBuilder  # flake8: noqa



import logging
import json
from rest_framework import serializers
from django.conf import settings

log = logging.getLogger(__name__)


def validate_reponse_limit(value):
    """
    value - a django response object
    """
    if len(value.content.encode('utf-8')) > 24:
        msg = "Alexa response content is bigger then 24 kilobytes"
        raise serializers.ValidationError(detail=msg)


def validate_app_ids(value):
    """
    value - an alexa app id
    """
    if value not in settings.ALEXA_APP_IDS:
        msg = "{0} is not a valid alexa skills application id"
        raise serializers.ValidationError(detail=msg.format(value))


def validate_current_timestamp(value):
    """
    value - a timestamp formatted in ISO 8601 (for example, 2015-05-13T12:34:56Z).
    """
    # TODO: flesh out current timestamp validation
    pass


def validate_char_limit(value):
    """
    value - a serializer to check to make sure the character limit is not excceed
    """
    # TODO: remove this logging once we validate the validator works
    log.info("CHAR VALIDATE: {0}".format(value))
    if len(json.dumps(value.data)) > 8000:
        msg = "{0} has exceeded the total character limit of 8000"
        raise serializers.ValidationError(detail=msg.format(value.__class__.__name__))


def validate_alexa_request(value):
    """
    value - a django request object
    """
    # TODO: validate alexa request headers
    # see https://github.com/anjishnu/ask-alexa-pykit/blob/master/lib/validation_utils.py
    log.info(value.META.items())
